# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .conversation_flow_component_response import ConversationFlowComponentResponse

__all__ = ["ConversationFlowComponentListResponse"]

ConversationFlowComponentListResponse: TypeAlias = List[ConversationFlowComponentResponse]
